@@ -11,7 +11,6 @@ from .preprocessors import Preprocessor, CleanHTML
 from .postprocessors import (
     JSONPostprocessor,
     PydanticPostprocessor,
-    HallucinationChecker,
 )
 
 
@@ -52,13 +51,12 @@ class SchemaScraper(OpenAiCall):
             json_type = "JSON object"
             _default_postprocessors = [
                 JSONPostprocessor(nudge=True),
-                HallucinationChecker(),
             ]
 
         if postprocessors is None:
             self.postprocessors = _default_postprocessors
         else:
-            self.postprocessors = _default_postprocessors + postprocessors
+            self.postprocessors = postprocessors
 
         self.system_messages = [
             f"For the given HTML, convert to a {json_type} matching this schema: "
